==> haskell-http-streams-0.8.6.1-46-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-http-streams.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-streams
version: 0.8.6.1
id: http-streams-0.8.6.1-K78V31gYQRQBPLwFEtmnMk
key: http-streams-0.8.6.1-K78V31gYQRQBPLwFEtmnMk
license: BSD-3-Clause
copyright: © 2012-2018 Operational Dynamics Consulting, Pty Ltd and Others
maintainer: Andrew Cowie <andrew@operationaldynamics.com>
author: Andrew Cowie <andrew@operationaldynamics.com>
stability: experimental
homepage: https://github.com/afcowie/http-streams/
synopsis: An HTTP client using io-streams
description:
    /Overview/
    .
    An HTTP client, using the Snap Framework'\''s '\''io-streams'\'' library to
    hande the streaming IO. The API is optimized for ease of use for the
    rather common case of code needing to query web services and deal with
    the result.
    .
    The library is exported in a single module; see "Network.Http.Client"
    for full documentation.
category: Web, IO-Streams
abi: 70b2d88af8e5498a85d6e7e345508d8f
exposed: True
exposed-modules:
    Network.Http.Client Network.Http.Connection
    Network.Http.Inconvenience Network.Http.ResponseParser
hidden-modules: Network.Http.Utilities
import-dirs: /usr/lib/ghc-8.4.3/site-local/http-streams-0.8.6.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/http-streams-0.8.6.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/http-streams-0.8.6.1
hs-libraries: HShttp-streams-0.8.6.1-K78V31gYQRQBPLwFEtmnMk
depends:
    attoparsec-0.13.2.2-5oKqcFqqk8HLoRElqn64fK base-4.11.1.0
    directory-1.3.1.5 base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37
    blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028 bytestring-0.10.8.2
    case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra
    io-streams-1.5.0.1-IYeBBvuoDFjClIohawF1WY
    HsOpenSSL-0.11.4.14-IPWvQrRLW0NCIn5oBY5ldK
    openssl-streams-1.2.1.3-DvS6rysEgUJ4scNTDrVfzw mtl-2.2.2
    transformers-0.5.5.0 text-1.2.3.0
    unordered-containers-0.2.9.0-IEc9LFcTDjK6w3ap4NqwQu
    aeson-1.4.0.0-5Oo1Sp1QUM1GMDoxqgB2DX
    http-common-0.8.2.0-4FaBGFZzjEDGrw6d8o3kjE
    network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9
    network-2.7.0.2-1OJnZsn219R1IXngT025LR
abi-depends: attoparsec-0.13.2.2-5oKqcFqqk8HLoRElqn64fK=fff7ae21f45c1b0af12007963cebbf81
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37=65adc4f5f54a1c07291b4ebc49756c05
             blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028=f952a1ec5abae3e4435518edbfd82e4e
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra=0a5994e39a32f328ff4f350b25844411
             io-streams-1.5.0.1-IYeBBvuoDFjClIohawF1WY=8b3312482f87aba091b27558a2717289
             HsOpenSSL-0.11.4.14-IPWvQrRLW0NCIn5oBY5ldK=d37d3f58c9f49e5b1d027e1ec6d33222
             openssl-streams-1.2.1.3-DvS6rysEgUJ4scNTDrVfzw=48eb9de11e658d107f70271059e5d528
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             unordered-containers-0.2.9.0-IEc9LFcTDjK6w3ap4NqwQu=5b052eced98346d45f3db03378f2841d
             aeson-1.4.0.0-5Oo1Sp1QUM1GMDoxqgB2DX=703c560734a72c2a014a198df0039e3a
             http-common-0.8.2.0-4FaBGFZzjEDGrw6d8o3kjE=03c0cdce5fe78e5a241e201c43f00682
             network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9=4ea8f0efa7a1ade0af4e9ce0cffcff8c
             network-2.7.0.2-1OJnZsn219R1IXngT025LR=3133613495d02f305adaa7a6ab03f465
haddock-interfaces: /usr/share/doc/haskell-http-streams/html/http-streams.haddock
haddock-html: /usr/share/doc/haskell-http-streams/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-streams-0.8.6.1-50-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-http-streams.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-streams
version: 0.8.6.1
id: http-streams-0.8.6.1-IO5jSlciyaC6A3fOdzQtOU
key: http-streams-0.8.6.1-IO5jSlciyaC6A3fOdzQtOU
license: BSD-3-Clause
copyright: © 2012-2018 Operational Dynamics Consulting, Pty Ltd and Others
maintainer: Andrew Cowie <andrew@operationaldynamics.com>
author: Andrew Cowie <andrew@operationaldynamics.com>
stability: experimental
homepage: https://github.com/afcowie/http-streams/
synopsis: An HTTP client using io-streams
description:
    /Overview/
    .
    An HTTP client, using the Snap Framework'\''s '\''io-streams'\'' library to
    hande the streaming IO. The API is optimized for ease of use for the
    rather common case of code needing to query web services and deal with
    the result.
    .
    The library is exported in a single module; see "Network.Http.Client"
    for full documentation.
category: Web, IO-Streams
abi: 119a99771bd252ab6d8f4ce14dde06db
exposed: True
exposed-modules:
    Network.Http.Client Network.Http.Connection
    Network.Http.Inconvenience Network.Http.ResponseParser
hidden-modules: Network.Http.Utilities
import-dirs: /usr/lib/ghc-8.4.3/site-local/http-streams-0.8.6.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/http-streams-0.8.6.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/http-streams-0.8.6.1
hs-libraries: HShttp-streams-0.8.6.1-IO5jSlciyaC6A3fOdzQtOU
depends:
    attoparsec-0.13.2.2-5oKqcFqqk8HLoRElqn64fK base-4.11.1.0
    directory-1.3.1.5 base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37
    blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028 bytestring-0.10.8.2
    case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra
    io-streams-1.5.0.1-IYeBBvuoDFjClIohawF1WY
    HsOpenSSL-0.11.4.14-IPWvQrRLW0NCIn5oBY5ldK
    openssl-streams-1.2.1.3-DvS6rysEgUJ4scNTDrVfzw mtl-2.2.2
    transformers-0.5.5.0 text-1.2.3.0
    unordered-containers-0.2.9.0-IEc9LFcTDjK6w3ap4NqwQu
    aeson-1.4.0.0-9qWiRNFZVktJndCRfB1Mai
    http-common-0.8.2.0-4FaBGFZzjEDGrw6d8o3kjE
    network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9
    network-2.7.0.2-1OJnZsn219R1IXngT025LR
abi-depends: attoparsec-0.13.2.2-5oKqcFqqk8HLoRElqn64fK=fff7ae21f45c1b0af12007963cebbf81
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37=65adc4f5f54a1c07291b4ebc49756c05
             blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028=f952a1ec5abae3e4435518edbfd82e4e
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra=0a5994e39a32f328ff4f350b25844411
             io-streams-1.5.0.1-IYeBBvuoDFjClIohawF1WY=8b3312482f87aba091b27558a2717289
             HsOpenSSL-0.11.4.14-IPWvQrRLW0NCIn5oBY5ldK=d37d3f58c9f49e5b1d027e1ec6d33222
             openssl-streams-1.2.1.3-DvS6rysEgUJ4scNTDrVfzw=48eb9de11e658d107f70271059e5d528
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             unordered-containers-0.2.9.0-IEc9LFcTDjK6w3ap4NqwQu=5b052eced98346d45f3db03378f2841d
             aeson-1.4.0.0-9qWiRNFZVktJndCRfB1Mai=107057a2dbf5fda7f784a80ae20f44b9
             http-common-0.8.2.0-4FaBGFZzjEDGrw6d8o3kjE=03c0cdce5fe78e5a241e201c43f00682
             network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9=4ea8f0efa7a1ade0af4e9ce0cffcff8c
             network-2.7.0.2-1OJnZsn219R1IXngT025LR=3133613495d02f305adaa7a6ab03f465
haddock-interfaces: /usr/share/doc/haskell-http-streams/html/http-streams.haddock
haddock-html: /usr/share/doc/haskell-http-streams/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
